@@ -303,6 +303,7 @@ public:
     SyncthingDev *findDevInfo(const QString &devId, int &row);
     const SyncthingDev *findDevInfo(const QString &devId, int &row) const;
     SyncthingDev *findDevInfoByName(const QString &devName, int &row);
+    Q_INVOKABLE QString fullPath(const QString &dirId, const QString &relativePath) const;
 
 #ifndef QT_NO_SSL
     const QList<QSslError> &expectedSslErrors() const;
@@ -373,6 +374,9 @@ public:
     QueryResult postConfigFromJsonObject(
         const QJsonObject &rawConfig, std::function<void(QString &&)> &&callback = std::function<void(QString &&)>());
     QueryResult postConfigFromByteArray(const QByteArray &rawConfig, std::function<void(QString &&)> &&callback = std::function<void(QString &&)>());
+    QueryResult sendCustomRequest(const QByteArray &verb, const QUrl &url,
+        const QMap<QByteArray, QByteArray> &headers = QMap<QByteArray, QByteArray>(), QIODevice *data = nullptr);
+    QueryResult downloadSupportBundle();
 
 Q_SIGNALS:
     void syncthingUrlChanged(const QString &newUrl);
@@ -515,6 +519,7 @@ private:
         QByteArray response;
     };
     QNetworkRequest prepareRequest(const QString &path, const QUrlQuery &query, bool rest = true, bool longPolling = false);
+    QNetworkRequest prepareRequest(const QUrl &url, bool longPolling = false);
     QNetworkReply *requestData(const QString &path, const QUrlQuery &query, bool rest = true, bool longPolling = false);
     QNetworkReply *postData(const QString &path, const QUrlQuery &query, const QByteArray &data = QByteArray());
     QNetworkReply *sendData(const QByteArray &verb, const QString &path, const QUrlQuery &query, const QByteArray &data = QByteArray());
@@ -646,6 +651,7 @@ inline const QString &SyncthingConnection::localPath() const
 
 /*!
  * \brief Sets the path of the Unix domain socket to connect to Syncthing.
+ * \remarks This path is only used when specifying a "unix+http://" URL via setSyncthingUrl().
  */
 inline void SyncthingConnection::setLocalPath(const QString &localPath)
 {
